@@ -3,7 +3,7 @@
 # Perl ARP Extension test file
 #
 # Programmed by Bastian Ballmann
-# Last update: 30.09.2004
+# Last update: 31.12.2004
 #
 # This program is free software; you can redistribute 
 # it and/or modify it under the terms of the 
@@ -21,14 +21,20 @@ use Net::ARP;
 use Net::Pcap;
 
 my $errbuf;
-#my $dev = Net::Pcap::lookupdev(\$errbuf);
-my $dev = "";
+my $dev = Net::Pcap::lookupdev(\$errbuf);
+
+#Net::ARP::send_packet($dev,                           # network interface
+#		      '127.0.0.1',                    # source ip
+#	              '127.0.0.1',                    # destination ip
+#		      'aa:bb:cc:aa:bb:cc',            # source mac
+#	              'aa:bb:cc:aa:bb:cc',            # destination mac
+#	              'reply');                       # ARP operation 
 
 Net::ARP::send_packet($dev,                           # network interface
 		      '127.0.0.1',                    # source ip
 	              '127.0.0.1',                    # destination ip
 		      'aa:bb:cc:aa:bb:cc',            # source mac
-	              'aa:bb:cc:aa:bb:cc',            # destination mac
+	              'ff:ff:ff:ff:ff:ff',            # destination mac
 	              'reply');                       # ARP operation 
 
 Net::ARP::get_mac($dev,$mac);
